<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Collection;
use Leenooks\Traits\CompositeKeys;

class SiteDetail extends Model
{
	use CompositeKeys;

	public $incrementing = false;
	protected $primaryKey = ['site_id','key'];
	public $timestamps = FALSE;

	/* RELATIONS */

	public function site()
	{
		return $this->belongsTo(Site::class);
	}

	/* ATTRIBUTES */

	public function getValueAttribute($value)
	{
		if (! $this->key)
			return $value;

		switch (gettype($this->_sampledata()->get($this->key))) {
			case 'array': return unserialize($value);
			default: return $value;
		}
	}

	public function setKeyAttribute($value)
	{
		if (! $this->_sampledata()->has($value))
			throw new \Exception(sprintf('Key [%s] is not expected.',$value));

		$this->attributes['key'] = $value;
	}

	public function setValueAttribute($value)
	{
		// Check that the value can be set
		if (! $this->key)
			throw new \Exception('Please set key first');

		// Check that the value is of the right type
		$x = $this->_sampledata()->get($this->key);

		if ($value && (! $this->checkType($value,$x)))
			throw new \Exception(sprintf('Value for [%s] is not the of the correct type [%s] for this attribute, expecting [%s].',$this->key,gettype($value),gettype($this->_sampledata()->get($this->key))));

		switch (gettype($x)) {
			case 'array':
				$this->attributes['value'] = serialize($value ?: []);
				break;

			default:
				$this->attributes['value'] = $value ?: '';
		}
	}

	/* GENERAL METHODS */

	/**
	 * Check that two variables are the same type
	 *
	 * @param $a
	 * @param $b
	 * @return bool
	 */
	private function checkType($a,$b): bool
	{
		return gettype($a) == gettype($b);
	}

	/**
	 * Pre-load this model with Sample Data, if there is no database record
	 */
	private function _sampleData(): Collection
	{
		return collect([
			/*
			'aboutus'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.',
			'activity'=>[
				['title'=>'Project 1','description'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.','subtitle'=>'Lorem ipsum dolor sit amet','image_small'=>'/image/generic/150/75/a00','image_large'=>'/image/generic/500/400/700'],
				['title'=>'Project 2','description'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.','subtitle'=>'Lorem ipsum dolor sit amet','image_small'=>'/image/generic/150/75/b00','image_large'=>'/image/generic/500/400/800'],
				['title'=>'Project 3','description'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.','subtitle'=>'Lorem ipsum dolor sit amet','image_small'=>'/image/generic/150/75/c00','image_large'=>'/image/generic/500/400/900'],
				['title'=>'Project 4','description'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.','subtitle'=>'Lorem ipsum dolor sit amet','image_small'=>'/image/generic/150/75/d00','image_large'=>'/image/generic/500/400/a00'],
			],
			'activity_intro'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.',
			'block_quotes'=>[
				[
					'title'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.',
					'image'=>'/image/generic/150/75/1A3AAA'
				],
			],
			'clients'=>[
				[
					'image'=>'/image/generic/200/100/999',
					'hover'=>'/image/generic/200/100/399',
				],
				[
					'image'=>'/image/generic/200/100/999',
					'hover'=>'/image/generic/200/100/499',
				],
				[
					'image'=>'/image/generic/200/100/999',
					'hover'=>'/image/generic/200/100/599',
				],
				[
					'image'=>'/image/generic/200/100/999',
					'hover'=>'/image/generic/200/100/699',
				],
				[
					'image'=>'/image/generic/200/100/999',
					'hover'=>'/image/generic/200/100/689',
				],
				[
					'image'=>'/image/generic/200/100/999',
					'hover'=>'/image/generic/200/100/679',
				],
				[
					'image'=>'/image/generic/200/100/999',
					'hover'=>'/image/generic/200/100/669',
				],
				[
					'image'=>'/image/generic/200/100/999',
					'hover'=>'/image/generic/200/100/659',
				],
				[
					'image'=>'/image/generic/200/100/999',
					'hover'=>'/image/generic/200/100/649',
				],
			],
			'clients_intro'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore',
			'language_id'=>1,
			'page_tabs'=>[
				[
					'title'=>'Title 1',
					'image'=>'/image/generic/200/100/999',
					'text'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua',

				],
				[
					'title'=>'Title 2',
					'image'=>'/image/generic/200/100/799',
					'text'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua',

				],
				[
					'title'=>'Title 3',
					'image'=>'/image/generic/200/100/979',
					'text'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua',
				],
			],
			'site_slider'=>[
				[
					'title'=>'Header <br/><span class="carousel-title-normal">and Title</span>',
					'text'=>'This is what you were looking for',
					'style'=>1,
					'image'=>'url(/image/generic/300/300/eee)',
					'button'=>['text'=>'Purchase Now','url'=>'#'],
				],
				[
					'title'=>'Header and Title',
					'text'=>'This is what you were looking for',
					'text2'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit.<br/>Sed est nunc, sagittis at consectetur id.',
					'style'=>2,
					'image'=>'url(/image/generic/400/400/ddd)',
					'button'=>['text'=>'Purchase Now','url'=>'#'],
				],
				[
					'title'=>'Header and Title',
					'text'=>'This is what you were looking for',
					'text2'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit.<br/>Sed est nunc, sagittis at consectetur id.',
					'style'=>2,
					'image'=>'url(/image/generic/500/500/eee)',
					//'button'=>['text'=>'Purchase Now','url'=>'#'],
				],
			],
			'services'=>[
				['title'=>'Title 1','text'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.','icon'=>'fa fa-location-arrow blue','image'=>NULL],
				['title'=>'Title 2','text'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.','icon'=>'fa fa-compress green','image'=>NULL],
				['title'=>'Title 3','text'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.','icon'=>'fa fa-check red','image'=>'/image/generic/200/100/999'],
			],
			*/
			'email_logo'=>route('image',['width'=>150,'height'=>20,'color'=>'eee']),
			'site_address1' => 'Address line 1',
			'site_address2' => 'Address line 2',
			'site_description'=>'Example Site',
			'site_email' => 'nobody@example.com',
			'site_city' => 'City',
			'site_fax'=>'+0 1 2345 6789',
			'site_name' => 'MY OSB SITE',
			'site_state' => 'State',
			'site_phone'=>'+0 1 2345 6789',
			'site_postcode' => '12345',
			'site_tax'=>'12 123 123 123',
			'site_logo'=>route('image',['width'=>128,'height'=>32,'color'=>'eee']),
			'social'=>[
				['name'=>'facebook','url'=>'http://www.facebook.com'],
				['name'=>'linkedin','url'=>'http://www.linkedin.com'],
				['name'=>'twitter','url'=>'http://www.twitter.com'],
			],
			/*
			'steps'=>[
				['title'=>'Title 1','description'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud'],
				['title'=>'Title 2','description'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud'],
				['title'=>'Title 3','description'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud'],
			],
			'testimonials'=>[
				[
					'title'=>'Title 1',
					'name'=>'Bart Simpson',
					'quote'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud',
					'photo'=>'/image/generic/200/100/999',
				],
				[
					'title'=>'Title 2',
					'name'=>'Lisa Simpson',
					'quote'=>'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud',
					'photo'=>'/image/generic/200/100/499',
				],
			],
			*/
			'top_menu'=>[
				'Home'=>['name'=>'Home','url'=>'/','children'=>[
					['name'=>'Link 1','url'=>'#/l2', 'children'=>[]],
					['name'=>'Link 2','url'=>'#/l2', 'children'=>[]],
				]],
				'Option1'=>['name'=>'Option 1','url'=>'/o1','children'=>[]],
				'Option2'=>['name'=>'Option 2','url'=>'/o2','children'=>[
					['name'=>'O2 Link 1','url'=>'#/o2l1', 'children'=>[]],
					['name'=>'O2 Link 1','url'=>'#/o2l2', 'children'=>[]],
				]],
			],
		]);
	}

	/**
	 * Get a sample key value
	 *
	 * @param $key
	 * @return mixed
	 * @throws \Exception
	 */
	public function sample($key)
	{
		if (! $x=$this->_sampledata()->get($key))
			throw new \Exception('Key doesnt exist: '.$key);

		return $x;
	}
}